@@ -17,7 +17,6 @@
 #' @author Jack W. Kostal
 #'
 #' @importFrom tibble as_tibble
-#' @importFrom reshape2 melt
 #'
 #' @examples
 #' ## Create a hypothetical matrix of data from a small study:
@@ -102,9 +101,13 @@ reshape_mat2dat <- function(var_names, cor_data, common_data = NULL, unique_data
 
      rownames(cor_data) <- colnames(cor_data) <- rownames(common_data) <- rownames(unique_data) <- var_names
 
-     cor_data_trans <- melt(cor_data,na.rm=TRUE)
-     cor_data_trans[,1:2] <- cor_data_trans[,2:1]
-     colnames(cor_data_trans) <- c("x_name", "y_name", "rxyi")
+     cor_data_trans <- .reshape_longer_matrix(
+             cor_data,
+             na.rm = TRUE,
+             varnames = c("x_name", "y_name"),
+             value.name = "rxyi",
+             rev = TRUE
+     )
 
      common_data_out <- common_data[cor_data_trans$x_name,]
      unique_data_x <- unique_data[cor_data_trans$x_name,]
@@ -335,7 +338,7 @@ reshape_wide2long <- function(data, common_vars = NULL, es_design = NULL, n_desi
                }
           }
 
-          new_data <- data.table::rbindlist(new_data, fill = TRUE)
+          new_data <- do.call(rbind, new_data)
 
      } else {
           # new_data <- data.frame(matrix(NA, 0, length(common_vars) + 4 + 2 * length(other_cnames)), stringsAsFactors = FALSE)
@@ -373,14 +376,7 @@ reshape_wide2long <- function(data, common_vars = NULL, es_design = NULL, n_desi
                     }
                }
           }
-
-          new_data <- data.table::rbindlist(new_data, fill = TRUE)
-     }
-
-     if (inherits(data, "tbl_df")) {
-       new_data <- as_tibble(new_data)
-     } else if (inherits(data, "data.frame")) {
-       new_data <- as.data.frame(new_data, stringsAsFactors = FALSE)
+          new_data <- do.call(rbind, new_data)
      }
      new_data
 }
@@ -470,3 +466,33 @@ reshape_vec2mat <- function(cov = NULL, var = NULL, order = NULL, var_names = NU
      mat
 }
 
+.reshape_longer_matrix <- function(
+  data,
+  varnames = names(dimnames(data)),
+  na.rm = FALSE,
+  value.name = "value",
+  rev = FALSE
+) {
+  if (! inherits(data, c("array", "data.frame"))) {
+    stop("'data' must be a matrix, array, or data.frame", call. = FALSE)
+  }
+  dn <- dimnames(data)
+  if (is.null(dn)) {
+    dn <- rep(list(NULL), length(dim(data)))
+  }
+  null_names <- which(unlist(lapply(dn, is.null)))
+  dn[null_names] <- lapply(null_names, function(i) seq_len(dim(data)[i]))
+  labels <- expand.grid(dn, KEEP.OUT.ATTRS = FALSE, stringsAsFactors = FALSE)
+  if (rev) {
+    labels <- rev(labels)
+  }
+  names(labels) <- varnames
+  if (na.rm) {
+    missing <- is.na(data)
+    data <- data[!missing]
+    labels <- labels[!missing, ]
+  }
+  value_df <- setNames(data.frame(as.vector(data)), value.name)
+  cbind(labels, value_df)
+}
+
